package cn.fw.valhalla.domain.query;

import cn.fw.valhalla.common.utils.DateUtil;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.math.NumberUtils;
import org.springframework.util.CollectionUtils;

import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author : kurisu
 * @className : CustomerCluePoolQueryVO
 * @description : 客户线索池查询
 * @date: 2020-11-20 15:49
 */
@Data
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
public class CustomerCluePoolQueryVO extends PoolQuery {
    private Integer type;
    private String startTime;
    /**
     * 线索状态
     */
    private Integer status;
    private String shopName;
    private String comShops;
    /**
     * 管理门店范围
     */
    private String scope;


    public Date getStartTime() {
        if (StringUtils.isNotBlank(startTime) && NumberUtils.isDigits(startTime)) {
            LocalDateTime localDateTime = Instant.ofEpochMilli(NumberUtils.toLong(startTime)).atZone(ZoneId.systemDefault()).toLocalDateTime();
            return DateUtil.localDateTime2Date(localDateTime);
        }
        return null;
    }


    public List<Long> getScope() {
        if (StringUtils.isBlank(scope)) {
            return null;
        }
        return Arrays.stream(scope.split(","))
                .filter(s -> StringUtils.isNotBlank(s) && NumberUtils.isDigits(s))
                .map(Long::valueOf).distinct()
                .collect(Collectors.toList());
    }

    public List<Long> getComShops() {
        if (StringUtils.isBlank(comShops)) {
            return null;
        }
        List<Long> list = Arrays.stream(comShops.split(",")).filter(StringUtils::isNoneBlank).map(Long::valueOf).collect(Collectors.toList());
        if (CollectionUtils.isEmpty(list)) {
            return null;
        }
        return list;
    }
}
