package cn.fw.valhalla.service.data.impl;

import cn.fw.valhalla.dao.mapper.StammkundePoolMapper;
import cn.fw.valhalla.domain.db.pool.StammkundePool;
import cn.fw.valhalla.domain.dto.StammkundePoolDTO;
import cn.fw.valhalla.domain.enums.StammkundeStatusEnum;
import cn.fw.valhalla.domain.query.StammkundePoolQueryVO;
import cn.fw.valhalla.service.data.StammkundePoolService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @author : kurisu
 * @className : StammkundePoolServiceImpl
 * @description : 保有客池
 * @date: 2020-11-11 17:25
 */
@Service
public class StammkundePoolServiceImpl extends ServiceImpl<StammkundePoolMapper, StammkundePool> implements StammkundePoolService {
    @Override
    public boolean reject(Long customerId, Long groupId) {
        return this.update(Wrappers.<StammkundePool>lambdaUpdate()
                .set(StammkundePool::getAktiv, Boolean.FALSE)
                .set(StammkundePool::getRejectTime, new Date())
                .eq(StammkundePool::getCustomerId, customerId)
                .eq(StammkundePool::getGroupId, groupId)
                .isNull(StammkundePool::getRejectTime)
        );
    }

    @Override
    public boolean reject(Long userId, Long shopId, Long groupId) {
        return this.update(Wrappers.<StammkundePool>lambdaUpdate()
                .set(StammkundePool::getAktiv, Boolean.FALSE)
                .set(StammkundePool::getRejectTime, new Date())
                .eq(StammkundePool::getAdviserId, userId)
                .eq(StammkundePool::getShopId, shopId)
                .eq(Objects.nonNull(groupId), StammkundePool::getGroupId, groupId)
                .isNull(StammkundePool::getRejectTime)
        );
    }

    @Override
    public void aktiv(Long customerId, Long groupId, Long shopId) {
        this.update(Wrappers.<StammkundePool>lambdaUpdate()
                .set(StammkundePool::getAktiv, Boolean.TRUE)
                .set(StammkundePool::getPoolStatus, StammkundeStatusEnum.KUNDE)
                .set(StammkundePool::getActivationTime, new Date())
                .eq(StammkundePool::getCustomerId, customerId)
                .eq(StammkundePool::getGroupId, groupId)
                .eq(StammkundePool::getShopId, shopId)
                .eq(StammkundePool::getAktiv, Boolean.FALSE)
                .isNull(StammkundePool::getRejectTime)
        );
    }

    @Override
    public void aktiv(Long id) {
        this.update(Wrappers.<StammkundePool>lambdaUpdate()
                .set(StammkundePool::getAktiv, Boolean.TRUE)
                .set(StammkundePool::getPoolStatus, StammkundeStatusEnum.KUNDE)
                .set(StammkundePool::getActivationTime, new Date())
                .eq(StammkundePool::getId, id)
                .eq(StammkundePool::getAktiv, Boolean.FALSE)
                .isNull(StammkundePool::getRejectTime)
        );
    }

    @Override
    public StammkundePool queryAktivAble(Long customerId, Long groupId, Long shopId) {
        return this.getOne(Wrappers.<StammkundePool>lambdaQuery()
                .eq(StammkundePool::getCustomerId, customerId)
                .eq(StammkundePool::getGroupId, groupId)
                .eq(StammkundePool::getShopId, shopId)
                .eq(StammkundePool::getAktiv, Boolean.FALSE)
                .isNull(StammkundePool::getRejectTime)
        );
    }

    @Override
    public List<StammkundePoolDTO> stammkundeList(StammkundePoolQueryVO queryVO) {
        Integer current = queryVO.getCurrent();
        Integer pageSize = queryVO.getPageSize();
        Integer startIndex = (current - 1) * pageSize;
        return Optional.ofNullable(getBaseMapper().stammkundeList(startIndex, pageSize, queryVO)).orElse(new ArrayList<>());
    }

    @Override
    public long stammkundeListCount(StammkundePoolQueryVO queryVO) {
        return Optional.ofNullable(getBaseMapper().stammkundeListCount(queryVO)).orElse(0L);
    }
}
